@@ -32,15 +32,7 @@ impl<const LITERAL: &'static str> Parse for Literal<LITERAL> {
 	fn parse(position: &mut Position) -> Result<Self>
 	where Self : Sized {
 
-		let start_position = position.clone();
-
-		let error = Error {
-
-			identifier: LITERAL.to_string(),
-			position: start_position.clone(),
-			cause: None
-
-		};
+		let error = Error::unexpected::<Self>(position.clone());
 		
 		let expected_range = position.index() .. position.index() + LITERAL.len() - 1;
 
@@ -57,8 +49,14 @@ impl<const LITERAL: &'static str> Parse for Literal<LITERAL> {
 
 			for _ in 0..length {
 
-				let _ = position.next();
-
+				if position.clone().next().is_none() {
+	
+					return Err(Error::unexpected_end::<Self>(position.clone()))
+	
+				}
+	
+				else { let _ = position.next(); }
+	
 			}
 
 			return Ok(Self);
